pub struct SnapshotBuilder { /* private fields */ }Expand description
Builder for creating snapshots.
Implementations
Sourceimpl SnapshotBuilder
impl SnapshotBuilder
Sourcepub fn version(self, version: impl Into<String>) -> Self
pub fn version(self, version: impl Into<String>) -> Self
Set the global version for this snapshot.
Sourcepub fn resources(
self,
type_url: TypeUrl,
resources: impl IntoIterator<Item = BoxResource>,
) -> Self
pub fn resources( self, type_url: TypeUrl, resources: impl IntoIterator<Item = BoxResource>, ) -> Self
Add resources of a specific type.
The version for this resource type defaults to the global version.
Sourcepub fn resources_with_version(
self,
type_url: TypeUrl,
version: impl Into<String>,
resources: impl IntoIterator<Item = BoxResource>,
) -> Self
pub fn resources_with_version( self, type_url: TypeUrl, version: impl Into<String>, resources: impl IntoIterator<Item = BoxResource>, ) -> Self
Add resources of a specific type with a custom version.
Sourcepub fn resource(self, type_url: TypeUrl, resource: BoxResource) -> Self
pub fn resource(self, type_url: TypeUrl, resource: BoxResource) -> Self
Add a single resource.