pub struct Watch { /* private fields */ }Expand description
A watch subscription for receiving snapshot updates.
When a snapshot is updated for a node, all active watches for that node receive the new snapshot through their channel.
Implementations