Watch

Struct Watch 

pub struct Watch { /* private fields */ }
A watch subscription for receiving snapshot updates.

When a snapshot is updated for a node, all active watches for that node receive the new snapshot through their channel.

Implementations

Source

impl Watch

pub fn id(&self) -> WatchId

Get the unique identifier for this watch.

pub fn node_hash(&self) -> NodeHash

Get the node hash this watch is subscribed to.

pub async fn recv(&mut self) -> Option<Arc<Snapshot>>

Receive the next snapshot update.

Returns None if the watch has been cancelled.

pub fn try_recv(&mut self) -> Result<Arc<Snapshot>, TryRecvError>

Try to receive a snapshot update without waiting.

Returns:

  • Ok(snapshot) if an update is available
  • Err(TryRecvError::Empty) if no update is available
  • Err(TryRecvError::Disconnected) if the watch has been cancelled